==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/demandelements/containerplan/stops/stop_containerstop/create/duration/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# force save additionals
netedit.forceSaveAdditionals()

# go to demand mode
netedit.supermodeDemand()

# go to container mode
netedit.containerMode()

# change container plan
netedit.changeContainerPlan("tranship: edge->edge", False)

# create route using two one
netedit.leftClick(referencePosition, 274, 400)
netedit.leftClick(referencePosition, 280, 60)

# press enter to create route
netedit.typeEnter()

# go to containerPlanMode mode
netedit.containerPlanMode()

# select container
netedit.leftClick(referencePosition, 85, 412)

# go to containerStopContainerStop mode
netedit.changeContainerPlanMode("stopContainer: containerStop")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 170, 40)

# set invalid container number
netedit.changeDefaultBoolValue(netedit.attrs.containerStopContainerStop.create.durationEnable)

# create containerStopContainerStop
netedit.leftClick(referencePosition, 182, 40)

# set invalid container number
netedit.changeDefaultBoolValue(netedit.attrs.containerStopContainerStop.create.durationEnable)

# set invalid container number
netedit.changeDefaultValue(netedit.attrs.containerStopContainerStop.create.duration, "dummy")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 184, 40)

# set invalid container number
netedit.changeDefaultValue(netedit.attrs.containerStopContainerStop.create.duration, "-20")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 186, 40)

# set invalid container number
netedit.changeDefaultValue(netedit.attrs.containerStopContainerStop.create.duration, "30.2")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 188, 40)

# press enter to create route
netedit.typeEnter()

# Check undo redo
netedit.undo(referencePosition, 2)
netedit.redo(referencePosition, 2)

# save routes
netedit.saveRoutes(referencePosition)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/demandelements/containerplan/stops/stop_containerstop/create/duration/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to demand mode
netedit.supermodeDemand()

# go to container mode
netedit.containerMode()

# change container plan
netedit.changeContainerPlan("tranship: edge", False)

# create route using two one
netedit.leftClick(referencePosition, 274, 400)
netedit.leftClick(referencePosition, 280, 60)

# press enter to create route
netedit.typeEnter()

# go to containerPlanMode mode
netedit.containerPlanMode()

# select container
netedit.leftClick(referencePosition, 85, 412)

# go to containerStopContainerStop mode
netedit.changeContainerPlanMode("stopContainer: containerStop")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 170, 40)

# set invalid container number
netedit.changeDefaultBoolValue(netedit.attrs.containerStopContainerStop.create.durationEnable)

# create containerStopContainerStop
netedit.leftClick(referencePosition, 182, 40)

# set invalid container number
netedit.changeDefaultBoolValue(netedit.attrs.containerStopContainerStop.create.durationEnable)

# set invalid container number
netedit.changeDefaultValue(netedit.attrs.containerStopContainerStop.create.duration, "dummy")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 184, 40)

# set invalid container number
netedit.changeDefaultValue(netedit.attrs.containerStopContainerStop.create.duration, "-20")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 186, 40)

# set invalid container number
netedit.changeDefaultValue(netedit.attrs.containerStopContainerStop.create.duration, "30.2")

# create containerStopContainerStop
netedit.leftClick(referencePosition, 188, 40)

# press enter to create route
netedit.typeEnter()

# Check undo redo
netedit.undo(referencePosition, 2)
netedit.redo(referencePosition, 2)

# save Netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
